#include <chronoptics/tof.hpp>
#include <iostream>

#include "data_structures.hpp"

namespace tof = chronoptics::tof;

void stream_frames() {
  auto cameras = tof::discover_kea_cameras();

  if (cameras.empty()) {
    std::cout << "No camera found\n";
    return;
  }

  // tof::KeaCamera cam(cameras.front().serial());
  tof::KeaCamera cam("202001a");
  std::cout << "Streaming from camera " << cam.get_serial() << "\n";

  tof::select_streams(cam, {tof::FrameType::Z, tof::FrameType::INTENSITY,
                            tof::FrameType::BGR_PROJECTED});

  cam.start();

  auto frames = cam.get_frames();

  for (auto &frame : frames) {
    switch (frame.frame_type()) {
      case tof::FrameType::Z: {
        float *z = cast_data_safe<float>(frame);
        std::cout << "Middle Z pixel value: " << z[153280] << "\n";
        break;
      }
      case tof::FrameType::INTENSITY: {
        uint8_t *intensity = cast_data_safe<uint8_t>(frame);
        std::cout << "Middle intensity pixel value: " << (int)intensity[153280]
                  << "\n";
        break;
      }
      case tof::FrameType::BGR_PROJECTED: {
        BGR *bgr = cast_data_safe<BGR>(frame);
        std::cout << "Middle blue pixel value: " << (int)bgr[153280].b << "\n";
        break;
      }
      default:
        std::cout << "Unexpected frame type\n";
        break;
    }
  }
}

int main() { stream_frames(); }